fsmonitor: rename new verbose config knob
authorBoris Feld <boris.feld@octobus.net>
Thu, 07 Feb 2019 17:04:15 +0100
changeset 41609 286eeed14893
parent 41608 67e622ade415
child 41610 d683aca738cd
fsmonitor: rename new verbose config knob The config knob was introduced in this release cycle under the old extension name, rename it before it is part of a release. Differential Revision: https://phab.mercurial-scm.org/D5880
hgext/fsmonitor/__init__.py
--- a/hgext/fsmonitor/__init__.py	Wed Feb 06 23:41:36 2019 -0500
+++ b/hgext/fsmonitor/__init__.py	Thu Feb 07 17:04:15 2019 +0100
@@ -161,7 +161,7 @@
 configitem('fsmonitor', 'blacklistusers',
     default=list,
 )
-configitem('hgwatchman', 'verbose',
+configitem('fsmonitor', 'verbose',
     default=True,
 )
 configitem('experimental', 'fsmonitor.transaction_notify',
@@ -175,13 +175,13 @@
 def _handleunavailable(ui, state, ex):
     """Exception handler for Watchman interaction exceptions"""
     if isinstance(ex, watchmanclient.Unavailable):
-        # experimental config: hgwatchman.verbose
-        if ex.warn and ui.configbool('hgwatchman', 'verbose'):
+        # experimental config: fsmonitor.verbose
+        if ex.warn and ui.configbool('fsmonitor', 'verbose'):
             ui.warn(str(ex) + '\n')
         if ex.invalidate:
             state.invalidate()
-        # experimental config: hgwatchman.verbose
-        if ui.configbool('hgwatchman','verbose'):
+        # experimental config: fsmonitor.verbose
+        if ui.configbool('fsmonitor', 'verbose'):
             ui.log('fsmonitor', 'Watchman unavailable: %s\n', ex.msg)
     else:
         ui.log('fsmonitor', 'Watchman exception: %s\n', ex)